@@ -1,5 +1,4 @@
 from abc import ABCMeta, abstractmethod
-from devsecops_engine_tools.engine_sast.engine_secret.src.domain.model.DeserializeConfigTool import DeserializeConfigTool
 
 class ToolGateway(metaclass=ABCMeta):
     @abstractmethod
@@ -11,8 +10,9 @@ class ToolGateway(metaclass=ABCMeta):
                             agent_os: str,
                             agent_work_folder: str,
                             repository_name: str,
-                            config_tool: DeserializeConfigTool,
+                            config_tool,
                             secret_tool,
                             secret_external_checks,
-                            agent_tem_dir:str) -> str:
+                            agent_tem_dir:str,
+                            tool) -> str:
         "run tool secret scan"
\ No newline at end of file
