@@ -1,8 +1,5 @@
 import re
-from devsecops_engine_tools.engine_core.src.domain.model.input_core import InputCore
-from devsecops_engine_tools.engine_sast.engine_secret.src.domain.model.DeserializeConfigTool import (
-    DeserializeConfigTool,
-)
+
 from devsecops_engine_tools.engine_sast.engine_secret.src.domain.model.gateway.tool_gateway import (
     ToolGateway,
 )
@@ -29,31 +26,35 @@ class SecretScan:
         self.tool_deserialize = tool_deserialize
         self.git_gateway = git_gateway
 
-    def process(self, skip_tool, config_tool, secret_tool, dict_args):
+    def process(self, skip_tool, config_tool, secret_tool, dict_args, tool):
+        tool = str(tool).lower()
         finding_list = []
         file_path_findings = ""
         secret_external_checks=dict_args["token_external_checks"]
+        files_to_scan = None if dict_args["folder_path"] is None else [dict_args["folder_path"]]
         if skip_tool == False:
-            self.tool_gateway.install_tool(self.devops_platform_gateway.get_variable("os"), self.devops_platform_gateway.get_variable("temp_directory"), config_tool.tool_version)
-            files_pullrequest = self.git_gateway.get_files_pull_request(
-                self.devops_platform_gateway.get_variable("path_directory"),
-                self.devops_platform_gateway.get_variable("target_branch"),
-                config_tool.target_branches,
-                self.devops_platform_gateway.get_variable("source_branch"),
-                self.devops_platform_gateway.get_variable("access_token"),
-                self.devops_platform_gateway.get_variable("organization"),
-                self.devops_platform_gateway.get_variable("project_name"),
-                self.devops_platform_gateway.get_variable("repository"),
-                self.devops_platform_gateway.get_variable("repository_provider"))
+            self.tool_gateway.install_tool(self.devops_platform_gateway.get_variable("os"), self.devops_platform_gateway.get_variable("temp_directory"), config_tool[tool]["VERSION"])
+            if files_to_scan is None:
+                files_to_scan = self.git_gateway.get_files_pull_request(
+                    self.devops_platform_gateway.get_variable("path_directory"),
+                    self.devops_platform_gateway.get_variable("target_branch"),
+                    config_tool["TARGET_BRANCHES"],
+                    self.devops_platform_gateway.get_variable("source_branch"),
+                    self.devops_platform_gateway.get_variable("access_token"),
+                    self.devops_platform_gateway.get_variable("organization"),
+                    self.devops_platform_gateway.get_variable("project_name"),
+                    self.devops_platform_gateway.get_variable("repository"),
+                    self.devops_platform_gateway.get_variable("repository_provider"))
             findings, file_path_findings = self.tool_gateway.run_tool_secret_scan(
-                    files_pullrequest,
+                    files_to_scan,
                     self.devops_platform_gateway.get_variable("os"),
                     self.devops_platform_gateway.get_variable("path_directory"),
                     self.devops_platform_gateway.get_variable("repository"),
                     config_tool,
                     secret_tool,
                     secret_external_checks,
-                    self.devops_platform_gateway.get_variable("temp_directory"))
+                    self.devops_platform_gateway.get_variable("temp_directory"),
+                    tool)
             finding_list = self.tool_deserialize.get_list_vulnerability(
                 findings,
                 self.devops_platform_gateway.get_variable("os"),
@@ -69,12 +70,11 @@ class SecretScan:
         init_config_tool = self.devops_platform_gateway.get_remote_config(
             dict_args["remote_config_repo"], "engine_sast/engine_secret/ConfigTool.json", dict_args["remote_config_branch"]
         )
-        config_tool = DeserializeConfigTool(json_data=init_config_tool, tool=tool)
-        config_tool.scope_pipeline = self.devops_platform_gateway.get_variable("pipeline_name")
+        init_config_tool['SCOPE_PIPELINE'] = self.devops_platform_gateway.get_variable("pipeline_name")
 
-        skip_tool = bool(re.match(config_tool.ignore_search_pattern, config_tool.scope_pipeline, re.IGNORECASE))
+        skip_tool = bool(re.match(init_config_tool["IGNORE_SEARCH_PATTERN"], init_config_tool["SCOPE_PIPELINE"], re.IGNORECASE))
         
-        return config_tool, skip_tool
+        return init_config_tool, skip_tool
         
     def skip_from_exclusion(self, exclusions, skip_tool_isp):
         """
